==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1DeploymentStrategyFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ExtensionsV1beta1DeploymentStrategyFluentImpl<A extends ExtensionsV1beta1DeploymentStrategyFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements ExtensionsV1beta1DeploymentStrategyFluent<A>{

    private ExtensionsV1beta1RollingUpdateDeploymentBuilder rollingUpdate;
    private String type;

    public ExtensionsV1beta1DeploymentStrategyFluentImpl(){
    }
    public ExtensionsV1beta1DeploymentStrategyFluentImpl(ExtensionsV1beta1DeploymentStrategy instance){
            this.withRollingUpdate(instance.getRollingUpdate());

            this.withType(instance.getType());

    }

    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public ExtensionsV1beta1RollingUpdateDeployment getRollingUpdate(){
            return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public ExtensionsV1beta1RollingUpdateDeployment buildRollingUpdate(){
            return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public A withRollingUpdate(ExtensionsV1beta1RollingUpdateDeployment rollingUpdate){
            _visitables.remove(this.rollingUpdate);
            if (rollingUpdate!=null){ this.rollingUpdate= new ExtensionsV1beta1RollingUpdateDeploymentBuilder(rollingUpdate); _visitables.add(this.rollingUpdate);} return (A) this;
    }

    public Boolean hasRollingUpdate(){
            return this.rollingUpdate != null;
    }

    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate(){
            return new RollingUpdateNestedImpl();
    }

    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(ExtensionsV1beta1RollingUpdateDeployment item){
            return new RollingUpdateNestedImpl(item);
    }

    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editRollingUpdate(){
            return withNewRollingUpdateLike(getRollingUpdate());
    }

    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate(){
            return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): new ExtensionsV1beta1RollingUpdateDeploymentBuilder().build());
    }

    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(ExtensionsV1beta1RollingUpdateDeployment item){
            return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): item);
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExtensionsV1beta1DeploymentStrategyFluentImpl that = (ExtensionsV1beta1DeploymentStrategyFluentImpl) o;
            if (rollingUpdate != null ? !rollingUpdate.equals(that.rollingUpdate) :that.rollingUpdate != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }


    public class RollingUpdateNestedImpl<N> extends ExtensionsV1beta1RollingUpdateDeploymentFluentImpl<ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<N>> implements ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final ExtensionsV1beta1RollingUpdateDeploymentBuilder builder;
    
            RollingUpdateNestedImpl(ExtensionsV1beta1RollingUpdateDeployment item){
                    this.builder = new ExtensionsV1beta1RollingUpdateDeploymentBuilder(this, item);
            }
            RollingUpdateNestedImpl(){
                    this.builder = new ExtensionsV1beta1RollingUpdateDeploymentBuilder(this);
            }
    
    public N and(){
            return (N) ExtensionsV1beta1DeploymentStrategyFluentImpl.this.withRollingUpdate(builder.build());
    }
    public N endRollingUpdate(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1DeploymentStrategyFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ExtensionsV1beta1DeploymentStrategyFluentImpl<A extends ExtensionsV1beta1DeploymentStrategyFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements ExtensionsV1beta1DeploymentStrategyFluent<A>{

    private ExtensionsV1beta1RollingUpdateDeploymentBuilder rollingUpdate;
    private String type;

    public ExtensionsV1beta1DeploymentStrategyFluentImpl(){
    }
    public ExtensionsV1beta1DeploymentStrategyFluentImpl(ExtensionsV1beta1DeploymentStrategy instance){
            this.withRollingUpdate(instance.getRollingUpdate());

            this.withType(instance.getType());

    }

    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public ExtensionsV1beta1RollingUpdateDeployment getRollingUpdate(){
            return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public ExtensionsV1beta1RollingUpdateDeployment buildRollingUpdate(){
            return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public A withRollingUpdate(ExtensionsV1beta1RollingUpdateDeployment rollingUpdate){
            _visitables.get("rollingUpdate").remove(this.rollingUpdate);
            if (rollingUpdate!=null){ this.rollingUpdate= new ExtensionsV1beta1RollingUpdateDeploymentBuilder(rollingUpdate); _visitables.get("rollingUpdate").add(this.rollingUpdate);} return (A) this;
    }

    public Boolean hasRollingUpdate(){
            return this.rollingUpdate != null;
    }

    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate(){
            return new RollingUpdateNestedImpl();
    }

    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(ExtensionsV1beta1RollingUpdateDeployment item){
            return new RollingUpdateNestedImpl(item);
    }

    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editRollingUpdate(){
            return withNewRollingUpdateLike(getRollingUpdate());
    }

    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate(){
            return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): new ExtensionsV1beta1RollingUpdateDeploymentBuilder().build());
    }

    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(ExtensionsV1beta1RollingUpdateDeployment item){
            return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): item);
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public A withNewType(String arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuilder arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1){
            return (A)withType(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExtensionsV1beta1DeploymentStrategyFluentImpl that = (ExtensionsV1beta1DeploymentStrategyFluentImpl) o;
            if (rollingUpdate != null ? !rollingUpdate.equals(that.rollingUpdate) :that.rollingUpdate != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }


    public class RollingUpdateNestedImpl<N> extends ExtensionsV1beta1RollingUpdateDeploymentFluentImpl<ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<N>> implements ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final ExtensionsV1beta1RollingUpdateDeploymentBuilder builder;
    
            RollingUpdateNestedImpl(ExtensionsV1beta1RollingUpdateDeployment item){
                    this.builder = new ExtensionsV1beta1RollingUpdateDeploymentBuilder(this, item);
            }
            RollingUpdateNestedImpl(){
                    this.builder = new ExtensionsV1beta1RollingUpdateDeploymentBuilder(this);
            }
    
    public N and(){
            return (N) ExtensionsV1beta1DeploymentStrategyFluentImpl.this.withRollingUpdate(builder.build());
    }
    public N endRollingUpdate(){
            return and();
    }

}


}
